/**
* This file is part of the QBittorrent Project
*
* Bittorrent Client using Qt4 and libtorrent.
* Copyright (C) 2006  Christophe Dumez
*
* This library is free software; you can redistribute it and/or
* modify it under the terms of the GNU Library General Public
* License as published by the Free Software Foundation; either
* version 2 of the License, or (at your option) any later version.
*
* This library is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
* Library General Public License for more details.
*
* You should have received a copy of the GNU Library General Public License
* along with this library; see the file COPYING.LIB.  If not, write to
* the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
* Boston, MA 02110-1301, USA.
**/

#include "screenedsearch.h"

/* QtCore */
#include <QtCore/QDebug>

/* QtGui */
#include <QtGui/QLineEdit>
#include <QtGui/QRadioButton>

ScreenedSearch::ScreenedSearch( QWidget * parent )
  : QGroupBox ( parent )
  , characters ( 3 )
{
  Q_ASSERT ( parent );
  setObjectName ( QLatin1String( "ScreenedSearch" ) );
  setupUi ( this );
  setEnabled( false );

  connect ( cmdInput, SIGNAL ( textChanged ( const QString & ) ),
           this, SLOT ( searchTextChanged ( const QString & ) ) );
}

void ScreenedSearch::searchTextChanged ( const QString &txt )
{
  QString buffer ( txt );
  buffer.trimmed();

  if ( buffer.length() <= charactersSet->value() )
  {
    emit prepareSearchResult ( QString() );
    return;
  }

  emit prepareSearchResult ( buffer );
  buffer.clear();
}

void ScreenedSearch::searchTextStart()
{
  searchTextChanged ( cmdInput->text() );
}

int ScreenedSearch::getCharacters()
{
  return charactersSet->value();
}

void ScreenedSearch::setCharacters ( int c )
{
  if ( c >= 3 )
  {
    characters = c;
    charactersSet->setValue(c);
  }
}

ScreenedSearch::~ScreenedSearch()
{
  cmdInput->clear();
}
