/**
* This file is part of the QBittorrent Project
*
* Bittorrent Client using Qt4 and libtorrent.
* Copyright (C) 2006  Christophe Dumez
*
* This library is free software; you can redistribute it and/or
* modify it under the terms of the GNU Library General Public
* License as published by the Free Software Foundation; either
* version 2 of the License, or (at your option) any later version.
*
* This library is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
* Library General Public License for more details.
*
* You should have received a copy of the GNU Library General Public License
* along with this library; see the file COPYING.LIB.  If not, write to
* the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
* Boston, MA 02110-1301, USA.
**/

#ifndef SCREENEDSEARCH_H
#define SCREENEDSEARCH_H

/* QtCore */
#include <QtCore/QMetaObject>
#include <QtCore/QObject>
#include <QtCore/QString>

/* QtGui */
#include <QtGui/QGroupBox>
#include <QtGui/QWidget>

/* UI */
#include "ui_screenedsearchmain.h"

/**
* \class ScreenedSearch
* \short this class provides methodes for filter search results
* \author Juergen Heinemann (Undfined) http://www.hjcms.de
*/
class ScreenedSearch : public QGroupBox, protected Ui::ScreenedSearchMain
{
  Q_OBJECT
  Q_CLASSINFO ( "Author", "Jürgen Heinemann (Undefined)" )
  Q_CLASSINFO ( "URL", "http://www.hjcms.de" )
  Q_PROPERTY ( int characters READ getCharacters WRITE setCharacters )

  private:
    int characters;

  private Q_SLOTS:
    void searchTextChanged ( const QString &txt );

  Q_SIGNALS:
    /** this signal is emitted whenever the text has changed more then \ref characters length!
    * \param txt  text to find or exclude from search result */
    void prepareSearchResult ( const QString &txt );

  public Q_SLOTS:
    void searchTextStart ();

  public:
    ScreenedSearch ( QWidget * parent = 0 );

    /** current text length when trigger \ref prepareSearchResult */
    int getCharacters();

    /** set minimum required text length before trigger \ref prepareSearchResult
    * \param c  default value is minimum 3 characters */
    void setCharacters ( int c );

    virtual ~ScreenedSearch();

};

#endif
